from __future__ import absolute_import, division, print_function

from stripe.api_resources.abstract.api_resource import APIResource


class SearchableAPIResource(APIResource):
    @classmethod
    def _search(
        cls,
        search_url,
        api_key=None,
        stripe_version=None,
        stripe_account=None,
        **params
    ):
        return cls._static_request(
            "get",
            search_url,
            api_key=api_key,
            stripe_version=stripe_version,
            stripe_account=stripe_account,
            params=params,
        )

    @classmethod
    def search(cls, *args, **kwargs):
        raise NotImplementedError

    @classmethod
    def search_auto_paging_iter(cls, *args, **kwargs):
        raise NotImplementedError



from __future__ import absolute_import, division, print_function

import stripe


TEST_RESOURCE_ID = "pts_123"


class TestSession(object):
    def test_is_creatable(self, request_mock):
        resource = stripe.billing_portal.Session.create(
            customer="cus_123", return_url="https://stripe.com/return"
        )
        request_mock.assert_requested("post", "/v1/billing_portal/sessions")
        assert isinstance(resource, stripe.billing_portal.Session)
